@@ -7,12 +7,12 @@ use warnings;
 
 package POSIX::1003::Module;
 use vars '$VERSION';
-$VERSION = '0.94_4';
+$VERSION = '0.94_5';
 
 
 # The VERSION of the distribution is sourced from this file, because
 # this module also loads the XS extension.
-our $VERSION = '0.94_4';
+our $VERSION = '0.94_5';
 use Carp 'croak';
 
 { use XSLoader;
@@ -35,8 +35,9 @@ BEGIN { $in_constant_table = qr/
  | ^POLL    # poll
  | ^_POSIX  # property
  | ^RLIM    # rlimit
- | ^_SC_    # sysconf
+ | ^SA_     # sigaction
  | ^S_      # stat
+ | ^_SC_    # sysconf
  | ^SEEK_   # fdio
  | ^SET_    # rlimit aix
  | ^SIG[^_] # signals
@@ -136,7 +137,7 @@ sub exampleValue($)
 
     my $tags      = \%{"$pkg\::EXPORT_TAGS"} or die;
     my $constants = $tags->{constants} || [];
-    grep {$_ eq $name} @$constants
+    grep $_ eq $name, @$constants
         or return undef;
 
     my $val = &{"$pkg\::$name"};
@@ -145,7 +146,7 @@ sub exampleValue($)
 
 package POSIX::1003::ReadOnlyTable;
 use vars '$VERSION';
-$VERSION = '0.94_4';
+$VERSION = '0.94_5';
 
 sub TIEHASH($) { bless $_[1], $_[0] }
 sub FETCH($)   { $_[0]->{$_[1]} }
